Hedgehog Robot Controller Server
================================

.. image:: https://travis-ci.org/PRIArobotics/HedgehogServer.svg?branch=master
    :target: https://travis-ci.org/PRIArobotics/HedgehogServer

This project provides the server for the Hedgehog Educational Robotics Controller.
Clients can communicate with it via the ZMQ & Protobuf based Hedgehog Protocol.
